@@ -21,7 +21,7 @@ from ..__version__ import __version__
 def analyze(
     ctx: click.Context,
 ) -> Union[str, int, None]:
-    """Analyzes a Robot Framework project.
+    """TODO: Analyzes a Robot Framework project.
 
     TODO: This is not implemented yet.
     """
